@@ -10,8 +10,8 @@ from queryable_properties.properties import (AnnotationMixin, CACHE_RETURN_VALUE
                                              LookupFilterMixin, QueryableProperty, queryable_property)
 from queryable_properties.utils import reset_queryable_property
 
-from ..models import (ApplicationWithClassBasedProperties, Category, DummyProperty, VersionWithClassBasedProperties,
-                      VersionWithDecoratorBasedProperties)
+from ..app_management.models import (ApplicationWithClassBasedProperties, Category, DummyProperty,
+                                     VersionWithClassBasedProperties, VersionWithDecoratorBasedProperties)
 
 
 def function_with_docstring():
@@ -114,15 +114,20 @@ class TestBasics(object):
         deserialized_prop = six.moves.cPickle.loads(serialized_prop)
         assert deserialized_prop is model.version
 
-    def test_representations(self):
-        string_representation = six.text_type(ApplicationWithClassBasedProperties.dummy)
-        object_representation = repr(ApplicationWithClassBasedProperties.dummy)
-        assert string_representation == 'tests.ApplicationWithClassBasedProperties.dummy'
-        assert object_representation == '<DummyProperty: {}>'.format(string_representation)
+    @pytest.mark.parametrize('prop, expected_str, expected_class_name', [
+        (ApplicationWithClassBasedProperties.dummy,
+         'tests.app_management.models.ApplicationWithClassBasedProperties.dummy', 'DummyProperty'),
+        (VersionWithClassBasedProperties.is_beta,
+         'tests.dummy_lib.models.ReleaseTypeModel.is_beta', 'ValueCheckProperty'),
+    ])
+    def test_representations(self, prop, expected_str, expected_class_name):
+        assert six.text_type(prop) == expected_str
+        assert repr(prop) == '<{}: {}>'.format(expected_class_name, expected_str)
 
     def test_invalid_property_name(self):
         with pytest.raises(QueryablePropertyError, match='must not contain the lookup separator'):
-            type('BrokenModel', (Model,), {'dummy__dummy': DummyProperty(), '__module__': 'tests.models'})
+            type('BrokenModel', (Model,),
+                 {'dummy__dummy': DummyProperty(), '__module__': 'tests.app_management.models'})
 
 
 class TestDecorators(object):
