@@ -6,9 +6,9 @@ import six
 from django import VERSION as DJANGO_VERSION
 from django.db import models
 
-from ..models import (ApplicationWithClassBasedProperties, ApplicationWithDecoratorBasedProperties,
-                      CategoryWithClassBasedProperties, CategoryWithDecoratorBasedProperties,
-                      VersionWithClassBasedProperties, VersionWithDecoratorBasedProperties)
+from ..app_management.models import (ApplicationWithClassBasedProperties, ApplicationWithDecoratorBasedProperties,
+                                     CategoryWithClassBasedProperties, CategoryWithDecoratorBasedProperties,
+                                     VersionWithClassBasedProperties, VersionWithDecoratorBasedProperties)
 
 pytestmark = [pytest.mark.django_db, pytest.mark.usefixtures('versions')]
 
